module GenZPK

  # Returns a string containing the erb template stored for the specified file.
  # @param [String] filename the filename the returned template will be used to generate
  # @return [String] the erb template for the specified file
  def getTemplate filename
    # Find the proper template for the specified file
    case filename
      when 'deployment.xml'
        template =<<-EOF
<?xml version="1.0" encoding="utf-8"?>
<package version="2.0" xmlns="http://www.zend.com/server/deployment-descriptor/1.0">
  <name><%= releaseName %></name>
  <summary> short description</summary>
  <description> long description</description>
  <version>
    <release><%= zpkVersion %></release>
  </version>
  <eula>data/LICENSE.txt</eula>
  <appdir></appdir>
  <docroot>public</docroot>
  <scriptsdir>scripts</scriptsdir>
  <dependencies>
    <required>
                <php>
                        <min>5.3.15</min>
                </php>
                <extension>
                        <name>pdo_mysql</name>
                </extension>
                <directive>
                        <name>memory_limit</name>
                        <min>16M</min>
                </directive>
    </required>
  </dependencies>
</package>
        EOF
      when 'pre_activate.php'
        template =<<-EOF
<?php
/* The script pre_activate.php should contain code that should make the changes in the server
 * environment so that the application is fully functional. For example, this may include
 * changing symbolic links to "data" directories from previous to current versions,
 * upgrading an existing DB schema, or setting up a "Down for Maintenance"
 * message on the live version of the application
 * The following environment variables are accessable to the script:
 *
 * - ZS_RUN_ONCE_NODE - a Boolean flag stating whether the current node is
 *   flagged to handle "Run Once" actions. In a cluster, this flag will only be set when
 *   the script is executed on once cluster member, which will allow users to write
 *   code that is only executed once per cluster for all different hook scripts. One example
 *   for such code is setting up the database schema or modifying it. In a
 *   single-server setup, this flag will always be set.
 * - ZS_WEBSERVER_TYPE - will contain a code representing the web server type
 *   ("IIS" or "APACHE")
 * - ZS_WEBSERVER_VERSION - will contain the web server version
 * - ZS_WEBSERVER_UID - will contain the web server user id
 * - ZS_WEBSERVER_GID - will contain the web server user group id
 * - ZS_PHP_VERSION - will contain the PHP version Zend Server uses
 * - ZS_APPLICATION_BASE_DIR - will contain the directory to which the deployed
 *   application is staged.
 * - ZS_CURRENT_APP_VERSION - will contain the version number of the application
 *   being installed, as it is specified in the package descriptor file
 * - ZS_PREVIOUS_APP_VERSION - will contain the previous version of the application
 *   being updated, if any. If this is a new installation, this variable will be
 *   empty. This is useful to detect update scenarios and handle upgrades / downgrades
 *   in hook scripts
 * - ZS_<PARAMNAME> - will contain value of parameter defined in deployment.xml, as specified by
 *   user during deployment.
 */


function fsmodify($obj) {
  $chunks = explode('/', $obj);
  if(is_dir($obj))
    chmod($obj, 0777);
}


function fsmodifyr($dir)
{
  if($objs = glob($dir."/*")) {
    foreach($objs as $obj) {
      fsmodify($obj);
      if(is_dir($obj)) fsmodifyr($obj);
    }
  }

  return fsmodify($dir);
}

fsmodifyr("$ZS_APPLICATION_BASE_DIR/public/images");
fsmodifyr("$ZS_APPLICATION_BASE_DIR/data/tmp");
fsmodifyr("$ZS_APPLICATION_BASE_DIR/data/saml");
fsmodifyr("$ZS_APPLICATION_BASE_DIR/data/direct-enrollment");
        EOF
      else
        # IF there isn't a template for that filename, give the user a nil string
        template = nil
    end

    # Return the template
    template
  end
end